@@ -24,7 +24,10 @@ def _import_all(modules: list):
                   f"[ERROR] Exception: {ex}")
 
 _import_all(MODULES)
+
 from FuncNotify.NotifyDecorators import *
+from FuncNotify.NotifyMethods import *
+NotifyTypes=NotifyMethods.get_cls_registry()
 
 
 import pkg_resources  # part of setuptools
